@@ -7,7 +7,7 @@ package Sub::HandlesVia;
 use Exporter::Shiny qw( delegations );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.006';
+our $VERSION   = '0.007';
 
 sub _generate_delegations {
 	my ($me, $name, $args, $globals) = (shift, @_);
@@ -444,6 +444,9 @@ aliases for existing methods.
                  set : SubHV         Moose       
                  sub : SubHV  DataP  Moose  Mouse
 
+  Scalar ==========================================
+    scalar_reference : SubHV                    
+
   String ==========================================
               append : SubHV  DataP  Moose  Mouse
                chomp : SubHV  DataP  Moose  Mouse
